==> gaea_operator-1.3.7.dev5-py3-none-any.whl: gaea_operator/config/svtr_lcnet/svtr_lcnet_config.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2024/3/1
# @Author  : yanxiaodong
# @File    : ppyoloeplus_config.py
"""
import os
from typing import Dict

from gaea_tracker import ExperimentTracker
from windmillclient.client.windmill_client import WindmillClient
from windmillmodelv1.client.model_api_model import ModelMetadata, InputSize

from gaea_operator.utils import DEFAULT_TRAIN_CONFIG_FILE_NAME, read_yaml_file, write_yaml_file
from ..config import Config
from .template.modify_train_parameter import generate_train_config, \
    set_multi_key_value, \
    KEY_EVAL_HEIGHT, \
    KEY_EVAL_WIDTH


class SVTRLCNetConfig(Config):
    """
    Config write for train, transform and package.
    """

    def __init__(self, windmill_client: WindmillClient, tracker_client: ExperimentTracker, metadata: Dict = {}):
        super().__init__(windmill_client=windmill_client, tracker_client=tracker_client, metadata=metadata)
        self.labels = []

    def write_train_config(self,
                           dataset_uri: str,
                           model_uri: str,
                           advanced_parameters: dict,
                           pretrain_model_uri: str):
        """
        Config write for train of ppyoloe_plus_m model.
        """
        new_advanced_parameters = advanced_parameters.copy()

        # 1. set dataset
        new_advanced_parameters['Train.dataset.label_file_list'] = [os.path.join(dataset_uri, 'train.txt')]
        new_advanced_parameters['Eval.dataset.label_file_list'] = [os.path.join(dataset_uri, 'val.txt')]

        # 2. generate train config file
        if not os.path.exists(model_uri):
            os.makedirs(model_uri, exist_ok=True)

        generate_train_config(new_advanced_parameters,
                              pretrain_model_uri,
                              os.path.join(model_uri, DEFAULT_TRAIN_CONFIG_FILE_NAME))

        self._update_train_metadata(advanced_parameters=new_advanced_parameters)

    def write_eval_config(self, dataset_uri: str, model_uri: str, ):
        """
        Config write for eval of ppyoloe_plus_m model.
        """
        parameters = {"Eval.dataset.label_file_list": [os.path.join(dataset_uri, "val.txt")]}

        config_data = read_yaml_file(model_uri, DEFAULT_TRAIN_CONFIG_FILE_NAME)
        for key, val in parameters.items():
            set_multi_key_value(config_data, key, val)

        write_yaml_file(config_data, model_uri, DEFAULT_TRAIN_CONFIG_FILE_NAME)

    def _update_train_metadata(self, advanced_parameters: Dict):
        """
        update train metadata
        """
        super()._update_train_metadata(advanced_parameters=advanced_parameters)
        model_meta = ModelMetadata(**self._metadata)

        input_size = InputSize(width=int(advanced_parameters[KEY_EVAL_WIDTH]),
                               height=int(advanced_parameters[KEY_EVAL_HEIGHT]))
        model_meta.inputSize = input_size

        model_meta.algorithmParameters.update({"mean": advanced_parameters["mean"],
                                               "std": advanced_parameters["std"]})

        self._metadata = model_meta.dict()

==> gaea_operator-4.5.2.dev1-py3-none-any.whl: gaea_operator/config/svtr_lcnet/svtr_lcnet_config.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2024/3/1
# @Author  : yanxiaodong
# @File    : ppyoloeplus_config.py
"""
import os
from typing import Dict

from gaea_tracker import ExperimentTracker
from windmillclient.client.windmill_client import WindmillClient
from windmillmodelv1.client.model_api_model import ModelMetadata, InputSize

from gaea_operator.utils import DEFAULT_TRAIN_CONFIG_FILE_NAME, read_yaml_file, write_yaml_file
from ..config import Config, \
    KEY_WORKER_NUM_STANDARD, \
    KEY_BATCH_SIZE_STANDARD, \
    KEY_EVAL_HEIGHT_STANDARD, \
    KEY_EVAL_WIDTH_STANDARD, \
    KEY_EPOCH_STANDARD
from .template.modify_train_parameter import generate_train_config, \
    set_multi_key_value, \
    KEY_EVAL_HEIGHT, \
    KEY_EVAL_WIDTH, \
    KEY_TRAIN_BATCH_SIZE, \
    KEY_WORKER_NUM


class SVTRLCNetConfig(Config):
    """
    Config write for train, transform and package.
    """

    def __init__(self, windmill_client: WindmillClient, tracker_client: ExperimentTracker, metadata: Dict = {}):
        super().__init__(windmill_client=windmill_client, tracker_client=tracker_client, metadata=metadata)
        self.labels = []

    def write_train_config(self,
                           dataset_uri: str,
                           model_uri: str,
                           advanced_parameters: dict,
                           pretrain_model_uri: str):
        """
        Config write for train of ppyoloe_plus_m model.
        """
        if KEY_EPOCH_STANDARD in advanced_parameters:
            advanced_parameters[KEY_EPOCH_STANDARD] = advanced_parameters.pop(KEY_EPOCH_STANDARD)
        if KEY_WORKER_NUM_STANDARD in advanced_parameters:
            advanced_parameters[KEY_WORKER_NUM] = advanced_parameters.pop(KEY_WORKER_NUM_STANDARD)
        if KEY_BATCH_SIZE_STANDARD in advanced_parameters:
            advanced_parameters[KEY_TRAIN_BATCH_SIZE] = advanced_parameters.pop(KEY_BATCH_SIZE_STANDARD)
        if KEY_EVAL_HEIGHT_STANDARD in advanced_parameters:
            advanced_parameters[KEY_EVAL_HEIGHT] = advanced_parameters.pop(KEY_EVAL_HEIGHT_STANDARD)
        if KEY_EVAL_WIDTH_STANDARD in advanced_parameters:
            advanced_parameters[KEY_EVAL_WIDTH] = advanced_parameters.pop(KEY_EVAL_WIDTH_STANDARD)

        new_advanced_parameters = advanced_parameters.copy()

        # 1. set dataset
        new_advanced_parameters['Train.dataset.label_file_list'] = [os.path.join(dataset_uri, 'train.txt')]
        new_advanced_parameters['Eval.dataset.label_file_list'] = [os.path.join(dataset_uri, 'val.txt')]

        # 2. generate train config file
        if not os.path.exists(model_uri):
            os.makedirs(model_uri, exist_ok=True)

        generate_train_config(new_advanced_parameters,
                              pretrain_model_uri,
                              os.path.join(model_uri, DEFAULT_TRAIN_CONFIG_FILE_NAME))

        self._update_train_metadata(advanced_parameters=new_advanced_parameters)

    def write_eval_config(self, dataset_uri: str, model_uri: str, ):
        """
        Config write for eval of ppyoloe_plus_m model.
        """
        parameters = {"Eval.dataset.label_file_list": [os.path.join(dataset_uri, "val.txt")]}

        config_data = read_yaml_file(model_uri, DEFAULT_TRAIN_CONFIG_FILE_NAME)
        for key, val in parameters.items():
            set_multi_key_value(config_data, key, val)

        write_yaml_file(config_data, model_uri, DEFAULT_TRAIN_CONFIG_FILE_NAME)

    def _update_train_metadata(self, advanced_parameters: Dict):
        """
        update train metadata
        """
        super()._update_train_metadata(advanced_parameters=advanced_parameters)
        model_meta = ModelMetadata(**self._metadata)

        input_size = InputSize(width=int(advanced_parameters[KEY_EVAL_WIDTH]),
                               height=int(advanced_parameters[KEY_EVAL_HEIGHT]))
        model_meta.inputSize = input_size

        model_meta.algorithmParameters.update({"mean": advanced_parameters["mean"],
                                               "std": advanced_parameters["std"]})

        self._metadata = model_meta.dict()
